import {HttpMethod, Route, StatusCodes} from 'org.crazydoctor.expressts';
import {Request, Response} from 'express';
import ServerApp from '..';
import { ISession } from '../session/ISession';
import DBEvents from '../db/DBEvents';

class GetDataStatistics extends Route {
	protected action = (req: Request, res: Response): any => {
		const session = req.session as ISession;
		
		if(!session.isEditor) {
			res.status(StatusCodes.FORBIDDEN).send('Access denied');
			return;
		}

		if(ServerApp.SourcesUpdating) {
			res.status(StatusCodes.ACCEPTED).send('Sources are being updated');
			return;
		}

		const { page, pageSize } = req.query;

		DBEvents.getStatisticsCount().then((count) => {
			DBEvents.getStatistics(parseInt(page as string), parseInt(pageSize as string)).then((statistics) => {
				res.set({
					'Content-Type': 'application/json'
				});
				res.status(StatusCodes.OK).send({ count: count, records: statistics });
			});
		});
	};

	protected method = HttpMethod.GET;
	protected order = 8;
	protected route = '/data/statistics';
}

export default GetDataStatistics;